@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 import threading
@@ -134,11 +134,18 @@ class OkeWorkloadIdentityResourcePrincipalSigner(SecurityTokenSigner):
              "reason": response.reason}, indent=2)))
 
         if not response.ok:
-            raise oci.exceptions.ServiceError(
-                response.status_code,
-                response.reason,
-                response.headers,
-                "Failed to get RPST token from proxymux")
+            if response.status_code == 403:
+                raise oci.exceptions.ServiceError(
+                    response.status_code,
+                    response.reason,
+                    response.headers,
+                    "Please ensure the cluster type is enhanced")
+            else:
+                raise oci.exceptions.ServiceError(
+                    response.status_code,
+                    response.reason,
+                    response.headers,
+                    "Failed to get RPST token from proxymux")
 
         try:
             decoded_response = base64.b64decode(response.content).decode("UTF-8")
