@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -23,7 +23,6 @@ from timeit import default_timer as timer
 from ._vendor import requests, six, urllib3, sseclient
 from dateutil.parser import parse
 from dateutil import tz
-
 import functools
 from six.moves.http_client import HTTPResponse
 
@@ -33,7 +32,7 @@ from .config import get_config_value_or_default, validate_config
 from .request import Request
 from .response import Response
 from .circuit_breaker import CircuitBreakerStrategy, NoCircuitBreakerStrategy
-from circuitbreaker import CircuitBreaker, CircuitBreakerMonitor
+from circuitbreaker import CircuitBreakerMonitor
 from .version import __version__
 from .util import NONE_SENTINEL, Sentinel, extract_service_endpoint
 missing = Sentinel("Missing")
@@ -51,6 +50,7 @@ enable_expect_header = True
 expect_header_env_var = os.environ.get('OCI_PYSDK_USING_EXPECT_HEADER', True)
 if isinstance(expect_header_env_var, six.string_types) and expect_header_env_var.lower() == "false":
     enable_expect_header = False
+oke_workload_refresh_enabled = os.environ.get('OCI_OKE_WORKLOAD_REFRESH_ENABLED', "True").lower() == "true"
 
 
 def merge_type_mappings(*dictionaries):
@@ -89,9 +89,12 @@ def _sanitize_headers_for_requests(headers):
     # Requests does not accept int or float values headers
     # Convert int, float and bool to string
     # Bools are automatically handled with this as bool is a subclass of int
+    # Convert a list of strings to csv string
     for header_name, header_value in six.iteritems(headers):
         if isinstance(header_value, six.integer_types) or isinstance(header_value, float):
             headers[header_name] = str(header_value)
+        if isinstance(header_value, list) and all(isinstance(item, str) for item in header_value):
+            headers[header_name] = ",".join(header_value)
     return headers
 
 
@@ -342,16 +345,10 @@ class BaseClient(object):
             # Enable Circuit breaker if a valid circuit breaker strategy is available
             if not isinstance(self.circuit_breaker_strategy, CircuitBreakerStrategy):
                 raise TypeError('Invalid Circuit Breaker Strategy!')
-            self.circuit_breaker_name = str(uuid.uuid4()) if self.circuit_breaker_strategy.name is None else self.circuit_breaker_strategy.name
             # Re-use Circuit breaker if sharing a Circuit Breaker Strategy.
-            circuit_breaker = CircuitBreakerMonitor.get(self.circuit_breaker_name)
+            circuit_breaker = CircuitBreakerMonitor.get(self.circuit_breaker_strategy.name)
             if circuit_breaker is None:
-                circuit_breaker = CircuitBreaker(
-                    failure_threshold=self.circuit_breaker_strategy.failure_threshold,
-                    recovery_timeout=self.circuit_breaker_strategy.recovery_timeout,
-                    expected_exception=self.circuit_breaker_strategy.expected_exception,
-                    name=self.circuit_breaker_name
-                )
+                circuit_breaker = self.circuit_breaker_strategy.get_circuit_breaker()
             # Equivalent to decorating the request function with Circuit Breaker
             self.request = circuit_breaker(self.request)
         self.logger.debug('Endpoint: {}'.format(self._endpoint))
@@ -431,7 +428,7 @@ class BaseClient(object):
                 isinstance(self.signer, signers.EphemeralResourcePrincipalSigner) or
                 isinstance(self.signer, signers.EphemeralResourcePrincipalV21Signer) or
                 isinstance(self.signer, signers.NestedResourcePrincipals) or
-                isinstance(self.signer, signers.OkeWorkloadIdentityResourcePrincipalSigner)):
+                (isinstance(self.signer, signers.OkeWorkloadIdentityResourcePrincipalSigner) and oke_workload_refresh_enabled)):
             return True
         else:
             return False
@@ -656,7 +653,7 @@ class BaseClient(object):
 
         initial_circuit_breaker_state = None
         if self.circuit_breaker_name:
-            initial_circuit_breaker_state = CircuitBreakerMonitor.get(self.circuit_breaker_name).state
+            initial_circuit_breaker_state = CircuitBreakerMonitor.get(self.circuit_breaker_strategy.name).state
             if initial_circuit_breaker_state != circuitbreaker.STATE_CLOSED:
                 self.logger.debug("Circuit Breaker State is {}!".format(initial_circuit_breaker_state))
 
@@ -710,15 +707,16 @@ class BaseClient(object):
             timestamp = datetime.now(timezone.utc).isoformat()
 
             service_code, message, deserialized_data = self.get_deserialized_service_code_and_message(response, allow_control_chars)
-            if response.status_code == 413 and service_code == 'RequestEntityTooLarge':
-                self.logger.warning("Recieved a 413/RequestEntityTooLarge from {}, resetting session".format(target_service))
+            if (response.status_code == 413 and service_code == 'RequestEntityTooLarge') or (response.status_code == 412 and service_code == 'IfNoneMatchFailed'):
+                self.logger.warning(
+                    f"Received a {response.status_code}/{service_code} from {target_service}, resetting session")
                 _ = response.content  # Read the response content to enable closing the socket.
                 response.close()
                 new_session = copy.copy(self.session)
                 self.session.close()
                 self.session = new_session
             if isinstance(self.circuit_breaker_strategy, CircuitBreakerStrategy) and self.circuit_breaker_strategy.is_transient_error(response.status_code, service_code):
-                new_circuit_breaker_state = CircuitBreakerMonitor.get(self.circuit_breaker_name).state
+                new_circuit_breaker_state = CircuitBreakerMonitor.get(self.circuit_breaker_strategy.name).state
                 if initial_circuit_breaker_state != new_circuit_breaker_state:
                     self.logger.warning("Circuit Breaker state changed from {} to {}".format(initial_circuit_breaker_state, new_circuit_breaker_state))
                 self.raise_transient_service_error(request, response, service_code, message, operation_name, api_reference_link, target_service, request_endpoint, client_version, timestamp, deserialized_data)
