@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 import io
@@ -74,6 +74,12 @@ class MultipartObjectAssembler:
         :param int part_size (optional):
             Override the default part size of 128 MiB, value is in bytes.
 
+        :param str opc_checksum_algorithm (optional):
+            The optional checksum algorithm to use to compute and store the checksum of the body of the HTTP request
+            (or the parts in case of multipart uploads), in addition to the default MD5 checksum.
+
+            Allowed values are: "CRC32C", "SHA256", "SHA384"
+
         :param str if_match (optional):
             The entity tag of the object to match.
 
@@ -129,6 +135,9 @@ class MultipartObjectAssembler:
         self.part_size = DEFAULT_PART_SIZE
         if 'part_size' in kwargs:
             self.part_size = kwargs['part_size']
+        self.opc_checksum_algorithm = None
+        if 'opc_checksum_algorithm' in kwargs:
+            self.opc_checksum_algorithm = kwargs['opc_checksum_algorithm']
         self.if_match = None
         if 'if_match' in kwargs:
             self.if_match = kwargs['if_match']
@@ -420,6 +429,9 @@ class MultipartObjectAssembler:
         if self.opc_sse_kms_key_id:
             kwargs['opc_sse_kms_key_id'] = self.opc_sse_kms_key_id
 
+        if self.opc_checksum_algorithm:
+            kwargs['opc_checksum_algorithm'] = self.opc_checksum_algorithm
+
         # pass on SSE-C values (if any)
         kwargs.update(self.ssec_params)
 
@@ -452,6 +464,9 @@ class MultipartObjectAssembler:
         # supply SSE-C key (if any) information to upload-part
         new_kwargs.update(self.ssec_params)
 
+        if self.opc_checksum_algorithm:
+            new_kwargs['opc_checksum_algorithm'] = self.opc_checksum_algorithm
+
         # TODO: Calculate the hash without needing to read the file chunk twice.
         # Calculate the hash before uploading.  The hash will be used
         # to determine if the part needs to be uploaded.  It will also
