@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 REGIONS_SHORT_NAMES = {
@@ -41,6 +41,11 @@ REGIONS_SHORT_NAMES = {
     'aga': 'us-saltlake-2',
     'bog': 'sa-bogota-1',
     'vap': 'sa-valparaiso-1',
+    'xsp': 'ap-singapore-2',
+    'ruh': 'me-riyadh-1',
+    'onm': 'ap-delhi-1',
+    'fyv': 'ap-kulai-1',
+    'hsg': 'ap-batam-1',
     'lfi': 'us-langley-1',
     'luf': 'us-luke-1',
     'ric': 'us-gov-ashburn-1',
@@ -63,8 +68,18 @@ REGIONS_SHORT_NAMES = {
     'str': 'eu-frankfurt-2',
     'beg': 'eu-jovanovac-1',
     'doh': 'me-dcc-doha-1',
+    'ebb': 'us-somerset-1',
+    'ebl': 'us-thames-1',
     'avz': 'eu-dcc-zurich-1',
-    'ahu': 'me-abudhabi-3'
+    'avf': 'eu-crissier-1',
+    'ahu': 'me-abudhabi-3',
+    'rba': 'me-alain-1',
+    'rkt': 'me-abudhabi-2',
+    'shj': 'me-abudhabi-4',
+    'dtz': 'ap-seoul-2',
+    'dln': 'ap-suwon-1',
+    'bno': 'ap-chuncheon-2',
+    'yxj': 'us-ashburn-2'
 }
 REGION_REALMS = {
     'ap-chuncheon-1': 'oc1',
@@ -105,6 +120,11 @@ REGION_REALMS = {
     'us-saltlake-2': 'oc1',
     'sa-bogota-1': 'oc1',
     'sa-valparaiso-1': 'oc1',
+    'ap-singapore-2': 'oc1',
+    'me-riyadh-1': 'oc1',
+    'ap-delhi-1': 'oc1',
+    'ap-kulai-1': 'oc1',
+    'ap-batam-1': 'oc1',
 
     'us-langley-1': 'oc2',
     'us-luke-1': 'oc2',
@@ -139,9 +159,23 @@ REGION_REALMS = {
 
     'me-dcc-doha-1': 'oc21',
 
-    'eu-dcc-zurich-1': 'oc24',
+    'us-somerset-1': 'oc23',
+    'us-thames-1': 'oc23',
 
-    'me-abudhabi-3': 'oc26'
+    'eu-dcc-zurich-1': 'oc24',
+    'eu-crissier-1': 'oc24',
+
+    'me-abudhabi-3': 'oc26',
+    'me-alain-1': 'oc26',
+
+    'me-abudhabi-2': 'oc29',
+    'me-abudhabi-4': 'oc29',
+
+    'ap-seoul-2': 'oc35',
+    'ap-suwon-1': 'oc35',
+    'ap-chuncheon-2': 'oc35',
+
+    'us-ashburn-2': 'oc42'
 }
 REALMS = {
     'oc1': 'oraclecloud.com',
@@ -156,8 +190,12 @@ REALMS = {
     'oc19': 'oraclecloud.eu',
     'oc20': 'oraclecloud20.com',
     'oc21': 'oraclecloud21.com',
+    'oc23': 'oraclecloud23.com',
     'oc24': 'oraclecloud24.com',
-    'oc26': 'oraclecloud26.com'
+    'oc26': 'oraclecloud26.com',
+    'oc29': 'oraclecloud29.com',
+    'oc35': 'oraclecloud35.com',
+    'oc42': 'oraclecloud42.com'
 }
 REGIONS = [
     'ap-chuncheon-1',
@@ -198,6 +236,11 @@ REGIONS = [
     'us-saltlake-2',
     'sa-bogota-1',
     'sa-valparaiso-1',
+    'ap-singapore-2',
+    'me-riyadh-1',
+    'ap-delhi-1',
+    'ap-kulai-1',
+    'ap-batam-1',
     'us-langley-1',
     'us-luke-1',
     'us-gov-ashburn-1',
@@ -220,6 +263,16 @@ REGIONS = [
     'eu-frankfurt-2',
     'eu-jovanovac-1',
     'me-dcc-doha-1',
+    'us-somerset-1',
+    'us-thames-1',
     'eu-dcc-zurich-1',
-    'me-abudhabi-3'
+    'eu-crissier-1',
+    'me-abudhabi-3',
+    'me-alain-1',
+    'me-abudhabi-2',
+    'me-abudhabi-4',
+    'ap-seoul-2',
+    'ap-suwon-1',
+    'ap-chuncheon-2',
+    'us-ashburn-2'
 ]
